@@ -2,23 +2,18 @@
 Common functions used by Splunk AppInspect checks
 """
 
-# Python Standard Libraries
 import os
 from collections import defaultdict
 
-# Third-Party Libraries
-import mako
-from mako.lexer import Lexer
-from mako.parsetree import TextTag, Code
 from mako.exceptions import MakoException
+from mako.lexer import Lexer
+from mako.parsetree import Code, TextTag
 
-# Custom Libraries
 from . import util
-from .find_spl_command_usage import find_spl_command_usage
 from .find_endpoint_usage import find_endpoint_usage
+from .find_spl_command_usage import find_spl_command_usage
 from .util import xml_node
 
-
 __all__ = [
     "blacklist_conf",
     "find_xml_nodes",
@@ -41,8 +36,8 @@ def blacklist_conf(app, reporter_action, conf_filename, failure_reason):
     if app.file_exists("default", conf_filename):
         file_path = os.path.join("default", conf_filename)
         reporter_output = (
-            "This file is prohibited/invalid. Details: {}."
-            " Please remove this file: {}".format(failure_reason, file_path)
+            f"This file is prohibited/invalid. Details: {failure_reason}."
+            f" Please remove this file: {file_path}"
         )
         reporter_action(reporter_output, file_path)
 
