@@ -391,14 +391,21 @@ def check_reload_trigger_for_all_custom_confs(app, reporter):
     # e.g. "banana.conf" -> "reload.banana" in app.conf
     for custom_conf in custom_confs:
         reload_option_name = f"reload.{os.path.splitext(custom_conf)[0]}"
-        if not app_conf.has_option("triggers", reload_option_name):
+        if app_conf.has_option("triggers", reload_option_name):
+            if app_conf.get_option("triggers", reload_option_name).value == "never":
+                reporter.warn(
+                    f"App contains custom conf(s) {custom_confs} but app.conf "
+                    f"have a [triggers] stanza has a setting value for reload of "
+                    f"'never' which would trigger restarts on any change to "
+                    f"the conf file, which may be a negative experience for end-users."
+                )
+        else:
             reporter.fail(
                 f"Custom conf file {custom_conf} does not have a reload trigger in app.conf. "
                 f"Without a reload trigger the app will request a restart on any change to the conf file, "
                 f"which may be a negative experience for end-users."
             )
 
-
 def _get_conf_permissions(default_meta):
     conf_permissions = {}
     meta_stanza_pattern = r"(?=\/).*"
