@@ -1,19 +1,12 @@
 # Copyright 2019 Splunk Inc. All rights reserved.
 """The configuration parsing logic for Splunk .conf files."""
-
-
-# Python Standard Libraries
 import re
 
-# Third-Party Libraries
 import chardet
 
-# Custom Libraries
-# N/A
-
 
 class InvalidSectionError(Exception):
-    """ Exception raised when a invalid section is found. """
+    """Exception raised when a invalid section is found."""
 
     def __init__(self, message="", file_name=None, line_no=None):
         super(InvalidSectionError, self).__init__(message)
@@ -65,7 +58,7 @@ def configuration_lexer(iterator):
             else:
                 yield ("RANDSTRING", item, lineno, error)
     except ValueError:
-        raise InvalidSectionError("Invalid item: {}".format(item), line_no=lineno)
+        raise InvalidSectionError(f"Invalid item: {item}", line_no=lineno)
     except Exception:
         # re-raise other errors, it might be code error that need to further investigation
         raise
@@ -88,7 +81,7 @@ def specification_lexer(iterator):
             else:
                 yield ("RANDSTRING", item, lineno, error)
     except ValueError:
-        raise InvalidSectionError("Invalid item: {}".format(item), line_no=lineno)
+        raise InvalidSectionError(f"Invalid item: {item}", line_no=lineno)
     except Exception:
         # re-raise other errors, it might be code error that need to further investigation
         raise
@@ -127,7 +120,7 @@ def parse(iterator_or_string, configuration_file, lexer):
                 configuration_file.add_error(error, lineno, current_section.name)
 
             if current_section.has_option(item[0]):
-                error_message = "Repeat item name '{}'".format(item[0])
+                error_message = f"Repeat item name '{item[0]}'"
                 configuration_file.add_error(
                     error_message, lineno, current_section.name
                 )
