@@ -3,6 +3,7 @@
 
 import logging
 import os
+import re
 
 import bs4
 
@@ -20,6 +21,17 @@ class FileResource(object):
     def exists(self):
         return os.path.isfile(self.file_path)
 
+    @property
+    def relative_path(self):
+        # remove top app folder name
+        return "/".join(self.app_file_path.split("/")[1:])
+
+    @property
+    def is_path_pointer(self):
+        if re.match(r".*\.path$", self.file_name):
+            return True
+        return False
+
     def parse(self, fmt):
         try:
             if fmt in ["xml", "lxml-xml", "lxml"]:
