@@ -5,8 +5,6 @@ Splunk AppInspect logger utility module
 """
 import logging
 
-import six
-
 
 def configure_logger(logger, log_level, log_file):
     """Intended to be used for the configuring the root logger of Python's
@@ -24,14 +22,9 @@ def configure_logger(logger, log_level, log_file):
 
     if log_file is not None:
 
-        if six.PY2:
-            logging_handler = logging.FileHandler(
-                log_file, mode="ab+", encoding="ascii", delay=False
-            )
-        else:
-            logging_handler = logging.FileHandler(
-                log_file, mode="a+", encoding="ascii", delay=False
-            )
+        logging_handler = logging.FileHandler(
+            log_file, mode="a+", encoding="ascii", delay=False
+        )
     else:
         # Default to STDOUT
         logging_handler = logging.StreamHandler(stream=None)
