@@ -4,8 +4,12 @@
 This module provides support for reading and writing AIFF and AIFF-C files
 """
 
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import TagConsts
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import tags
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import (
+    TagConsts,
+)
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import (
+    tags,
+)
 
 
 @tags(TagConsts.FILE_READ_AND_WRITE)
@@ -13,4 +17,4 @@ def open():
     """
     open file or file-like object using aifc.open(), return Aifc_read objects
     """
-    pass
\ No newline at end of file
+    pass
