@@ -165,13 +165,13 @@ class JSSplunkVisualizationsMatcher(RegexMatcher):
         super(JSSplunkVisualizationsMatcher, self).__init__(possible_splunkvisualizations_regex_patterns)
 
 
-class JSIFrameMatcher(RegexMatcher):
+class FrameMatcher(RegexMatcher):
     def __init__(self):
 
         possible_iframe_regex_patterns = [
             RegexBundle(r'(<iframe[^>]*src=[\'"]([^\'">]*)[\'"][^>]*>)')
         ]
-        super(JSIFrameMatcher, self).__init__(possible_iframe_regex_patterns)
+        super(FrameMatcher, self).__init__(possible_iframe_regex_patterns)
 
 
 class JSConsoleLogMatcher(RegexMatcher):
