@@ -4,8 +4,9 @@ Represent a version like splunk_7_2_0
 """
 import re
 from builtins import filter
-from .util import normalizeBoolean
-from .telemetry import telemetry_whitelist
+
+from .telemetry import telemetry_whitelist  # noqa: F401
+from .util import normalizeBoolean  # noqa: F401
 
 
 class TargetSplunkVersion(object):
@@ -39,7 +40,7 @@ class TargetSplunkVersion(object):
         return self._target_version_value > self._version_value(other)
 
     def __str__(self):
-        return "<{}: {}>".format(self.__class__.__name__, self._target_version_value)
+        return f"<{self.__class__.__name__}: {self._target_version_value}>"
 
     __repr__ = __str__
 
